@@ -31,6 +31,8 @@
 #include <qa_gr_fxpt.h>
 #include <qa_gr_fxpt_nco.h>
 #include <qa_gr_fxpt_vco.h>
+#include <qa_gr_math.h>
+#include <qa_gri_lfsr.h>
 
 CppUnit::TestSuite *
 qa_general::suite ()
@@ -42,6 +44,8 @@ qa_general::suite ()
   s->addTest (qa_gr_fxpt::suite ());
   s->addTest (qa_gr_fxpt_nco::suite ());
   s->addTest (qa_gr_fxpt_vco::suite ());
+  s->addTest (qa_gr_math::suite ());
+  s->addTest (qa_gri_lfsr::suite ());
   
   return s;
 }
