@@ -24,9 +24,14 @@
 #define INCLUDED_GR_TRIGGER_MODE_H
 
 enum gr_trigger_mode {
-  gr_TRIG_AUTO,			// auto trigger (on anything)
-  gr_TRIG_POS_SLOPE,		// trigger on positive slope across trigger level
-  gr_TRIG_NEG_SLOPE		// trigger on negative slope across trigger level
+  gr_TRIG_MODE_FREE,
+  gr_TRIG_MODE_AUTO,
+  gr_TRIG_MODE_NORM,
+};
+
+enum gr_trigger_slope {
+  gr_TRIG_SLOPE_POS,
+  gr_TRIG_SLOPE_NEG,
 };
 
 #endif /* INCLUDED_GR_TRIGGER_MODE_H */
