@@ -62,6 +62,9 @@ def pick_subdevice(u):
     return usrp.pick_subdev(u, (usrp_dbid.TV_RX,
                                 usrp_dbid.TV_RX_REV_2,
 				usrp_dbid.TV_RX_REV_3,
+				usrp_dbid.TV_RX_MIMO,
+                                usrp_dbid.TV_RX_REV_2_MIMO,
+				usrp_dbid.TV_RX_REV_3_MIMO,
                                 usrp_dbid.BASIC_RX))
 
 
