@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2006 Free Software Foundation, Inc.
+ * Copyright 2006,2010 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio.
  *
@@ -59,8 +59,8 @@ class audio_osx_sink : public gr_sync_block {
   UInt32              d_n_channels;
   UInt32              d_queueSampleCount, d_max_sample_count;
   bool                d_do_block;
-  mld_mutex_ptr       d_internal;
-  mld_condition_ptr   d_cond_data;
+  gruel::mutex*       d_internal;
+  gruel::condition_variable* d_cond_data;
   circular_buffer<float>** d_buffers;
 
 // AudioUnits and Such
