@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2006 Free Software Foundation, Inc.
+ * Copyright 2006,2010 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio.
  *
@@ -66,8 +66,8 @@ class audio_osx_source : public gr_sync_block {
   UInt32              d_n_AvailableInputFrames, d_n_ActualInputFrames;
   UInt32              d_n_user_channels, d_n_max_channels, d_n_deviceChannels;
   bool                d_do_block, d_passThrough, d_waiting_for_data;
-  mld_mutex_ptr       d_internal;
-  mld_condition_ptr   d_cond_data;
+  gruel::mutex*       d_internal;
+  gruel::condition_variable* d_cond_data;
   circular_buffer<float>** d_buffers;
 
 // AudioUnits and Such
