@@ -21,13 +21,20 @@ public:
   TimeDomainDisplayPlot(QWidget*);
   virtual ~TimeDomainDisplayPlot();
 
-  void PlotNewData(const double* realDataPoints, const double* imagDataPoints, const int64_t numDataPoints);
+  void PlotNewData(const double* realDataPoints, const double* imagDataPoints, 
+		   const int64_t numDataPoints, const double timeInterval);
     
   void SetImaginaryDataVisible(const bool);
 				   
   virtual void replot();
 
   void set_yaxis(double min, double max);
+  void set_xaxis(double min, double max);
+
+public slots:
+  void resizeSlot( QSize *s );
+  void SetSampleRate(double sr, double units, 
+		     const std::string &strunits);
 
 protected slots:
   void LegendEntryChecked(QwtPlotItem *plotItem, bool on);
@@ -47,11 +54,11 @@ private:
   double* _imagDataPoints;
   double* _xAxisPoints;
 
+  double _sampleRate;
+
   timespec _lastReplot;
 
   int64_t _numPoints;
-
-  double _displayIntervalTime;
 };
 
 #endif /* TIME_DOMAIN_DISPLAY_PLOT_HPP */
