@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004,2008 Free Software Foundation, Inc.
+ * Copyright 2004,2008,2009 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -26,7 +26,7 @@
 
 #include <usrp_source_base.h>
 #include <gr_io_signature.h>
-#include <usrp_standard.h>
+#include <usrp/usrp_standard.h>
 #include <assert.h>
 #include <cstdio>
 
@@ -292,6 +292,10 @@ usrp_source_base::pick_rx_subdevice()
     USRP_DBID_FLEX_2400_RX,
     USRP_DBID_TV_RX,
     USRP_DBID_TV_RX_REV_2,
+    USRP_DBID_TV_RX_REV_3,
+    USRP_DBID_TV_RX_MIMO,
+    USRP_DBID_TV_RX_REV_2_MIMO,
+    USRP_DBID_TV_RX_REV_3_MIMO,
     USRP_DBID_DBS_RX,
     USRP_DBID_BASIC_RX
   };
